==> dingo_python-1.0.3-py3-none-any.whl: dingo/model/llm/openai.py <==
import json
import time

from dingo.model import Model
from dingo.model.modelres import ModelRes
from dingo.model.llm.base import BaseLLM
from dingo.config.config import DynamicLLMConfig
from dingo.utils import log

try:
    from openai import OpenAI
except ImportError as e:
    log.warning("=========== openai register fail. Please check whether install OpenAI. ===========")


@Model.llm_register('openai')
class Openai(BaseLLM):
    client = None

    custom_config = DynamicLLMConfig(
        prompt="""
Assume you are a pre-trainer of an artificial intelligence language model. You are now examining a piece of text data scraped from the internet. Your task is to decide whether this data is suitable for training a large language model.
There are many criteria that you need to consider. They are listed below in order of importance, along with examples of how to apply them:

relevance: check whether the data contains irrelevant information. Irrelevant information refers to author, reporter, source, publisher, lead-in content, copyright, statement, references, date, a call to action at the beginning or end. 

After assessing the data based on these criteria, give a score that reflects the cumulative suitability of the data for training. 
Score has only two value: 0 and 1. A score of 0 indicates the data hits at least one of the criteria mentioned above. A score of 1 indicates the data does not hit any of the criteria mentioned above.

Type is one of the list: ["ineffectiveness", "incompleteness", "disunderstandability", "dissimilarity", "disfluency", "irrelevance", "insecurity"]. 
If score is 1, type is "high-quality".

Reason is explanation for the scoring.

Return answer in JSON format: {"score": 0, "type":"xxx", "reason": "xxx"}.
Please remember to output only the JSON FORMAT, without any additional content.
        
        
Here is the data you need to evaluate:
        """
    )

    @classmethod
    def create_client(cls):
        cls.client = OpenAI(api_key=cls.custom_config.key, base_url=cls.custom_config.api_url)

    @classmethod
    def call_api(cls, input_data: str) -> ModelRes:
        if cls.client is None:
            cls.create_client()
        messages = [
            # {"role": "system",
            # "content": "你是 Kimi，由 Moonshot AI 提供的人工智能助手，你更擅长中文和英文的对话。你会为用户提供安全，有帮助，准确的回答。同时，你会拒绝一切涉及恐怖主义，种族歧视，黄色暴力等问题的回答。Moonshot AI 为专有名词，不可翻译成其他语言。"},
            # {"role": "user", "content": "你好，我叫李雷，1+1等于多少？"},
            {"role": "user", "content": cls.custom_config.prompt + input_data}
        ]

        attempts = 0
        except_msg = ''
        while attempts < 3:
            try:
                completion = cls.client.chat.completions.create(
                    model=cls.custom_config.path,
                    messages=messages,
                    temperature=0.3,
                )
                response = str(completion.choices[0].message.content)
                log.info(response)

                if 'gpt' in cls.custom_config.path:
                    if response.startswith('```json'):
                        response = response[7:]
                    if response.endswith('```'):
                        response = response[:-3]
                res_json = json.loads(response)

                return ModelRes(
                    error_status=False if res_json['score'] == 1 else True,
                    error_type='QUALITY_IRRELEVANCE',
                    error_name=res_json['type'],
                    error_reason=response
                )
            except Exception as e:
                attempts += 1
                time.sleep(1)
                except_msg = str(e)

        return ModelRes(
            error_status=True,
            error_type='QUALITY_IRRELEVANCE',
            error_name="API_LOSS",
            error_reason=except_msg
        )

==> dingo_python-1.0.4-py3-none-any.whl: dingo/model/llm/openai.py <==
import json
import time

from dingo.model import Model
from dingo.model.llm.prompts.manager import get_prompt
from dingo.model.modelres import ModelRes
from dingo.io import MetaData
from dingo.model.llm.base import BaseLLM
from dingo.config.config import DynamicLLMConfig
from dingo.utils import log

try:
    from openai import OpenAI
except ImportError as e:
    log.warning("=========== openai register fail. Please check whether install OpenAI. ===========")


@Model.llm_register('openai')
class Openai(BaseLLM):
    client = None

    custom_config = DynamicLLMConfig(prompt_id="CONTEXT_RELEVANCE_PROMPT")

    @classmethod
    def create_client(cls):
        cls.client = OpenAI(api_key=cls.custom_config.key, base_url=cls.custom_config.api_url)

    @classmethod
    def call_api(cls, input_data: MetaData) -> ModelRes:
        if cls.client is None:
            cls.create_client()
        messages = [
            # {"role": "system",
            # "content": "你是 Kimi，由 Moonshot AI 提供的人工智能助手，你更擅长中文和英文的对话。你会为用户提供安全，有帮助，准确的回答。同时，你会拒绝一切涉及恐怖主义，种族歧视，黄色暴力等问题的回答。Moonshot AI 为专有名词，不可翻译成其他语言。"},
            # {"role": "user", "content": "你好，我叫李雷，1+1等于多少？"},
            {"role": "user", "content": get_prompt(cls.custom_config) + input_data.content}
        ]

        attempts = 0
        except_msg = ''
        while attempts < 3:
            try:
                completion = cls.client.chat.completions.create(
                    model=cls.custom_config.path,
                    messages=messages,
                    temperature=0.3,
                )
                response = str(completion.choices[0].message.content)
                log.info(response)

                if 'gpt' in cls.custom_config.path:
                    if response.startswith('```json'):
                        response = response[7:]
                    if response.endswith('```'):
                        response = response[:-3]
                res_json = json.loads(response)

                return ModelRes(
                    error_status=False if res_json['score'] == 1 else True,
                    error_type='QUALITY_IRRELEVANCE',
                    error_name=res_json['type'],
                    error_reason=response
                )
            except Exception as e:
                attempts += 1
                time.sleep(1)
                except_msg = str(e)

        return ModelRes(
            error_status=True,
            error_type='QUALITY_IRRELEVANCE',
            error_name="API_LOSS",
            error_reason=except_msg
        )
